#!/bin/bash
# Script to install a prebuilt package

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

gcnano_install_lib() {
    # Init for lib dir install
    gcnano_libdir=$1
    gcnano_libdir_install=$2
    # Init for include dir install
    gcnano_incdir=$3
    gcnano_incdir_install=$4
    # Init for package config install
    gcnano_pkgdir=$5
    gcnano_pkgdir_install=$6

    # Install libraries & headers
    log_exec install -m 0755 -d $gcnano_libdir_install
    log_exec install -m 0755 -d $gcnano_incdir_install

    # Install libraries
    log_exec install -m 0555 $gcnano_libdir/libGAL.so $gcnano_libdir_install
    log_exec install -m 0555 $gcnano_libdir/libVSC.so $gcnano_libdir_install
    # Install includes
    log_exec install -m 0755 -d $gcnano_incdir_install/KHR
    log_exec install -m 0644 $gcnano_incdir/KHR/* $gcnano_incdir_install/KHR

    for lib in egl gbm glesv1 glesv2 vg; do
		case $lib in
		    "egl")
				# Install libraries
				find $gcnano_libdir/* -type f -name libEGL.so.* -exec install -m 0555 '{}' $gcnano_libdir_install \;
				# Install includes
				log_exec install -m 0755 -d $gcnano_incdir_install/EGL
				log_exec install -m 0644 $gcnano_incdir/EGL/* $gcnano_incdir_install/EGL
				# Install pkgconfig
				log_exec install -m 0755 -d $gcnano_pkgdir_install
				log_exec install -m 0644 $gcnano_pkgdir/egl.pc $gcnano_pkgdir_install
				;;
		    "gbm")
				# Install libraries
				find $gcnano_libdir/* -type f -name libgbm.so.* -exec install -m 0555 '{}' $gcnano_libdir_install \;
				log_exec install -m 0755 $gcnano_libdir/libgbm_viv.so $gcnano_libdir_install
				# Install includes
				log_exec install -m 0755 -d $gcnano_incdir_install
				log_exec install -m 0644 $gcnano_incdir/gbm.h $gcnano_incdir_install
				# Install pkgconfig
				log_exec install -m 0755 -d $gcnano_pkgdir_install
				log_exec install -m 644 $gcnano_pkgdir/gbm.pc $gcnano_pkgdir_install
				;;
		    "glesv1")
				# Install libraries
				find $gcnano_libdir/* -type f -name libGLESv1_CM.so.* -exec install -m 0555 '{}' $gcnano_libdir_install \;
				# Install includes
				log_exec install -m 0755 -d $gcnano_incdir_install/GLES
				log_exec install -m 0644 $gcnano_incdir/GLES/* $gcnano_incdir_install/GLES
				# Install pkgconfig
				log_exec install -m 0755 -d $gcnano_pkgdir_install
				log_exec install -m 644 $gcnano_pkgdir/glesv1_cm.pc $gcnano_pkgdir_install
				;;
		    "glesv2")
				# Install libraries
				log_exec install -m 0555 $gcnano_libdir/libGLSLC.so $gcnano_libdir_install
				find $gcnano_libdir/* -type f -name libGLESv2.so.* -exec install -m 0555 '{}' $gcnano_libdir_install \;
				# Install includes
				log_exec install -m 0755 -d $gcnano_incdir_install/GLES2
				log_exec install -m 0644 $gcnano_incdir/GLES2/* $gcnano_incdir_install/GLES2
				# Hack for weston & kmscube compilation
				# Weston and kmscube use GLES3 header but the decision to use gles2 or gles3
				# are made a runtime
				log_exec install -m 0755 -d $gcnano_incdir_install/GLES3
				log_exec install -m 0644 $gcnano_incdir/GLES3/* $gcnano_incdir_install/GLES3
				# Install pkgconfig
				log_exec install -m 0755 -d $gcnano_pkgdir_install
				log_exec install -m 644 $gcnano_pkgdir/glesv2.pc $gcnano_pkgdir_install
				;;
		    "vg")
				# Install libraries
				find $gcnano_libdir/* -type f -name libOpenVG*.so.* -exec install -m 0555 '{}' $gcnano_libdir_install \;
				# Install includes
				log_exec install -m 0755 -d $gcnano_incdir_install/VG
				log_exec install -m 0644 $gcnano_incdir/VG/* $gcnano_incdir_install/VG
				# Install pkgconfig
				log_exec install -m 0755 -d $gcnano_pkgdir_install
				log_exec install -m 644 $gcnano_pkgdir/vg.pc $gcnano_pkgdir_install
				;;
		esac
    done
}

gcnano_install_symlinks() {
    # Init for lib dir install
    gcnano_libdir=$1
    gcnano_lib_symlink_dir_install=$2

    message "Create symlinks to shared libs in $gcnano_lib_symlink_dir_install folder (mandatory for SDK)"
    # Init relative path for symlinks
    relative_path=$(realpath -m --relative-to=$gcnano_lib_symlink_dir_install $gcnano_libdir)
    # Move to gcnano_lib_symlink_dir_install for symlinks
    cd "$gcnano_lib_symlink_dir_install"
    for sharelib in $(find $gcnano_libdir -type f -name "*.so*"); do
		# Get full libname
		sharelib_name=$(basename $sharelib)
		# Get base libname
		dev_lib_name=$(echo $sharelib_name | awk -F'.so' '{print $1}').so
		# Get SONAME
		soname_lib_name=$(objdump -x $sharelib 2>/dev/null | grep SONAME | awk -F' ' '{print $NF}')
		# Create symlink
		for link_name in $soname_lib_name $dev_lib_name; do
		    if [ -e "$link_name" ]; then
				message "Already existing share lib: $link_name. No symlink created in $gcnano_lib_symlink_dir_install."
		    elif [ ! -e "$relative_path/$sharelib_name" ]; then
				message "Not able to find share lib: $relative_path/$sharelib_name. No symlink created in $gcnano_lib_symlink_dir_install."
		    else
				log_exec ln -sf $sharelib_name $link_name
		    fi
		done
    done
    cd "${buildDir}"
}


function local_do_make_install() {
    # Update pkgconfig files info
    for pkg_file in $(find ${buildDir}/pkgconfig/* -type f -name *.pc); do
		sed -e "s;#PREFIX#;${prefix};g" -e "s;#VERSION#;22.0.3;g" -i $pkg_file
    done

    # Install gcnano libraries
    gcnano_install_lib  "${buildDir}/release/drivers" "${installDir}/${libdir}" \
			"${buildDir}/release/include" "${installDir}${includedir}" \
			"${buildDir}/pkgconfig" "${installDir}${libdir}/pkgconfig"

    # Manage creation of additional development symlinks to solve missing libs issue on SDK side
    # when GCNANO_USERLAND_OUTPUT_LIBDIR differs from libdir
    gcnano_install_symlinks "${installDir}/${libdir}" "${installDir}${libdir}"
}

do_buildstep_prepend

local_do_make_install

do_buildstep_append

